netapp_ontap.models.event_remediations_source API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.event_remediations_source`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class EventRemediationsSourceSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the EventRemediationsSource object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `object_id GET POST PATCH`

    The object_id field of the event_remediations_source.

    Example: 5666

  `object_type GET POST PATCH`

    The object_type field of the event_remediations_source.

    Valid choices:

    - inventory.ontap.fas.Cluster